Index: trunk/SophyaPI/PI/pigraphuc.cc
===================================================================
--- trunk/SophyaPI/PI/pigraphuc.cc	(revision 2091)
+++ trunk/SophyaPI/PI/pigraphuc.cc	(revision 2092)
@@ -169,13 +169,4 @@
   UC_CheckMinMaxDiff(ymin, ymax);
 
-  //  xym = fabs(xmax+xmin); xym = (xym > PETIT_DBLE) ? xym : PETIT_DBLE;
-  //  if ((xmax-xmin)/xym < PREC_DBLE) {xmin=xmin-PREC_DBLE/2.*xym; xmax=xmin+PREC_DBLE*xym;}
-  //  xym = fabs(ymax+ymin); xym = (xym > PETIT_DBLE) ? xym : PETIT_DBLE;
-  //  if ((ymax-ymin)/xym < PREC_DBLE) {ymin=ymin-PREC_DBLE/2.*xym; ymax=ymin+PREC_DBLE*xym;}
-//  if (xmax <= xmin  || ymax <= ymin) {
-//    cerr << "PIGraphicUC::SetUCS() Error - xmax <= xmin  || ymax <= ymin ! " << endl;
-//    return; 
-//    }
-
   if (!UC_CheckFinite(xmin, xmax) || !UC_CheckFinite(ymin, ymax)) {
     cerr << "PIGraphicUC::SetUCS() Error - Non finite value for x/ymin-max ! " << endl;
Index: trunk/SophyaPI/PI/piimage.cc
===================================================================
--- trunk/SophyaPI/PI/piimage.cc	(revision 2091)
+++ trunk/SophyaPI/PI/piimage.cc	(revision 2092)
@@ -15,4 +15,6 @@
 #include "piyfxdrw.h"
 #include PIAPP_H
+
+#define PERC_GARDE 0.05
 
 //++
@@ -1188,6 +1190,6 @@
   }
 }
-ymin -= 0.05*(ymax-ymin);
-ymax += 0.05*(ymax-ymin);
+ymin -= PERC_GARDE*(ymax-ymin);
+ymax += PERC_GARDE*(ymax-ymin);
 cutscw->SetLimits(xmin, xmax, ymin, ymax);
 //cutscw->UpdateLimits();
Index: trunk/SophyaPI/PI/piscdrawwdg.cc
===================================================================
--- trunk/SophyaPI/PI/piscdrawwdg.cc	(revision 2091)
+++ trunk/SophyaPI/PI/piscdrawwdg.cc	(revision 2092)
@@ -12,6 +12,4 @@
 #include "piaxestools.h"
 
-//define PETIT_DBLE 1.e-39
-//define PREC_DBLE  1.e-5
 #define PETIT_DBLE 1.e-100
 #define PREC_DBLE  1.e-16
Index: trunk/SophyaPI/PI/pisurfdr.cc
===================================================================
--- trunk/SophyaPI/PI/pisurfdr.cc	(revision 2091)
+++ trunk/SophyaPI/PI/pisurfdr.cc	(revision 2092)
@@ -5,4 +5,6 @@
 #include <math.h>
 #include "pisurfdr.h"
+
+#define PERC_GARDE 0.05
 
 //++
@@ -63,5 +65,5 @@
   double zmin = mZmin; 
   double zmax = mZmax;
-  double dzz = (mZmax-mZmin)*0.05;
+  double dzz = (mZmax-mZmin)*PERC_GARDE;
   mLut = new LUT(zmin-dzz*2, zmax-dzz, 256);
 
@@ -96,5 +98,5 @@
   x3Min = xmin;   x3Max = xmax;
   y3Min = ymin;   y3Max = ymax;
-  z3Min = zmin-0.05*(zmax-zmin);   z3Max = zmax+0.05*(zmax-zmin);
+  z3Min = zmin-PERC_GARDE*(zmax-zmin); z3Max = zmax+PERC_GARDE*(zmax-zmin);
 
 //  printf("PISurfaceDrawer::UpdateLimits() : %g-%g  %g-%g  %g-%g (%g) \n", xmin,xmax,ymin,ymax,zmin,zmax,D);
@@ -128,6 +130,7 @@
   PIGraphic3D* g3 = (PIGraphic3D*)(g);
 #endif
-  Draw3DBoxe(g3, XMin3(), XMax3(), YMin3(), YMax3(), ZMin3(), ZMax3(),
-                 mXmin, mXmax, mYmin, mYmax, mZmin-0.05*(mZmax-mZmin), mZmax+0.05*(mZmax-mZmin));
+  Draw3DBoxe(g3,XMin3(),XMax3(),YMin3(),YMax3(),ZMin3(),ZMax3(),
+            mXmin,mXmax,mYmin,mYmax,
+            mZmin-PERC_GARDE*(mZmax-mZmin),mZmax+PERC_GARDE*(mZmax-mZmin));
 }
 
Index: trunk/SophyaPI/PI/piyfxdrw.cc
===================================================================
--- trunk/SophyaPI/PI/piyfxdrw.cc	(revision 2091)
+++ trunk/SophyaPI/PI/piyfxdrw.cc	(revision 2092)
@@ -7,4 +7,6 @@
 #include "piyfxdrw.h"
 #include "parradapter.h"
+
+#define PERC_GARDE 0.02
 
 // --------------------------------------------------------------------------
@@ -101,7 +103,6 @@
 
   double dx, dy;
-  dx = 0.02*(xmax-xmin);
-  dy = 0.02*(ymax-ymin);
-
+  dx = PERC_GARDE*(xmax-xmin);
+  dy = PERC_GARDE*(ymax-ymin);
   SetLimits(xmin-dx, xmax+dx, ymin-dy, ymax+dy);
   SetAxesFlags(kBoxAxes | kExtTicks | kLabels);
Index: trunk/SophyaPI/PIext/pigfd1.cc
===================================================================
--- trunk/SophyaPI/PIext/pigfd1.cc	(revision 2091)
+++ trunk/SophyaPI/PIext/pigfd1.cc	(revision 2092)
@@ -4,4 +4,5 @@
 #include "pigfd1.h"
 
+#define PERC_GARDE 0.02
  
 /* --Methode-- */
@@ -47,6 +48,6 @@
 if(xmax<=xmin) xmax = xmin+1.;
 if(ymax<=ymin) ymax = ymin+1.;
-dx = 0.02*(xmax-xmin);
-dy = 0.02*(ymax-ymin);
+dx = PERC_GARDE*(xmax-xmin);
+dy = PERC_GARDE*(ymax-ymin);
 SetLimits((double)xmin-dx,(double)xmax+dx,(double)ymin-dy,(double)ymax+dy);
 SetAxesFlags(kBoxAxes | kExtTicks | kLabels);
Index: trunk/SophyaPI/PIext/pintup3d.cc
===================================================================
--- trunk/SophyaPI/PIext/pintup3d.cc	(revision 2091)
+++ trunk/SophyaPI/PIext/pintup3d.cc	(revision 2092)
@@ -5,4 +5,6 @@
 #include <stdio.h>
 #include "pintup3d.h"
+
+//#define PERC_GARDE 0.05
 
 //++
@@ -146,10 +148,10 @@
             (xmin+xmax)/2.+D , (ymin+ymax)/2.-2.5*D , zmin+(zmax-zmin)*0.85, 0.25, 0.25);  
 
-  x3Min = xmin;  // - 0.05*(xmax-xmin);
-  x3Max = xmax;  // + 0.05*(xmax-xmin);
-  y3Min = ymin;  // - 0.05*(ymax-ymin);
-  y3Max = ymax;  // + 0.05*(ymax-ymin);
-  z3Min = zmin;  // - 0.05*(zmax-zmin);
-  z3Max = zmax;  // + 0.05*(zmax-zmin);
+  x3Min = xmin;  // - PERC_GARDE*(xmax-xmin);
+  x3Max = xmax;  // + PERC_GARDE*(xmax-xmin);
+  y3Min = ymin;  // - PERC_GARDE*(ymax-ymin);
+  y3Max = ymax;  // + PERC_GARDE*(ymax-ymin);
+  z3Min = zmin;  // - PERC_GARDE*(zmax-zmin);
+  z3Max = zmax;  // + PERC_GARDE*(zmax-zmin);
 
 //  printf("PINTuple3D::UpdateLimits() : %g .. %g  %g .. %g  %g .. %g (%g) \n", xmin,xmax,ymin,ymax,zmin,zmax,D);
Index: trunk/SophyaPI/PIext/pintuple.cc
===================================================================
--- trunk/SophyaPI/PIext/pintuple.cc	(revision 2091)
+++ trunk/SophyaPI/PIext/pintuple.cc	(revision 2092)
@@ -5,4 +5,6 @@
 #include <stdio.h>
 #include "pintuple.h"
+
+#define PERC_GARDE 0.02
 
 //++
@@ -131,6 +133,6 @@
   mNT->GetMinMax(yK, ymin, ymax);
     
-  dx = 0.02*(xmax-xmin);
-  dy = 0.02*(ymax-ymin);
+  dx = PERC_GARDE*(xmax-xmin);
+  dy = PERC_GARDE*(ymax-ymin);
   
   SetLimits(xmin-dx, xmax+dx, ymin-dy, ymax+dy);
Index: trunk/SophyaPI/PIext/pistlist.cc
===================================================================
--- trunk/SophyaPI/PIext/pistlist.cc	(revision 2091)
+++ trunk/SophyaPI/PIext/pistlist.cc	(revision 2092)
@@ -4,4 +4,6 @@
 #include <stdio.h>
 #include "pistlist.h"
+
+#define PERC_GARDE 0.02
 
 //++
@@ -86,6 +88,6 @@
   mStL->CalcXYLimits(x1, x2, y1, y2);
   
-  dx = 0.02*(x2-x1);
-  dy = 0.02*(y2-y1);
+  dx = PERC_GARDE*(x2-x1);
+  dy = PERC_GARDE*(y2-y1);
   
   SetLimits(x1-dx, x2+dx, y1-dy, y2+dy); 

Index: trunk/SophyaPI/PI/piaxes.cc
===================================================================
--- trunk/SophyaPI/PI/piaxes.cc	(revision 2091)
+++ trunk/SophyaPI/PI/piaxes.cc	(revision 2092)
@@ -8,4 +8,6 @@
 #include <math.h>
 #include "piaxes.h"
+
+#define PERC_GARDE 0.02
 
 inline void dble_SWAP(double& a,double& b) {double tmp=a; a=b; b=tmp;}
@@ -365,5 +367,5 @@
  //cout<<"BestTicksLog: xmin="<<xmin<<" xmax="<<xmax<<" nticks="<<nticks<<endl;
 
- // CMV_BUG: quand on fait func 1 100 ..., Reza renvoit xmin=-0.9602 !!!
+ // CMV_BUG: quand on fait func x 1 100 ..., Reza renvoit xmin=-0.9602 !!!
  // Ceci est un bricolo qui permet d'obtenir un resultat moyen.
  // A CORRIGER: pour Reza, ne pas surdimensionner la fenetre
@@ -372,7 +374,6 @@
  if(xmin<=0.) {
    cout<<"Error_BestTicksLog: xmin="<<xmin;
-   double percor=0.05;
-   // On suppose que: xmin = xmin0 - percor*(xmax0-xmin0)
-   xmin = fabs((xmin+percor*xmax)/(1.+percor));
+   // On suppose que: xmin = xmin0 - PERC_GARDE*(xmax0-xmin0)
+   xmin = fabs((xmin+PERC_GARDE*xmax)/(1.+PERC_GARDE));
    cout<<" corrected to xmin="<<xmin<<endl
        <<"      ===> First labels may be WRONG"<<endl;